/*
 * Tencent is pleased to support the open source community by making 蓝鲸 available.
 * Copyright (C) 2017-2018 THL A29 Limited, a Tencent company. All rights reserved.
 * Licensed under the MIT License (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 * http://opensource.org/licenses/MIT
 * Unless required by applicable law or agreed to in writing, software distributed under
 * the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language governing permissions and
 * limitations under the License.
 */

package service

import (
	"configcenter/src/common"
	"configcenter/src/common/http/rest"
	"configcenter/src/common/metadata"
	"configcenter/src/storage/driver/mongodb"
)

// CommitTransaction to commit transaction
func (s *coreService) CommitTransaction(ctx *rest.Contexts) {
	cap := new(metadata.TxnCapable)
	if err := ctx.DecodeInto(cap); err != nil {
		ctx.RespErrorCodeOnly(common.CCErrCommHTTPInputInvalid, "decode transaction request body failed, err: %v", err)
		return
	}

	err := mongodb.Client().CommitTransaction(ctx.Kit.Ctx, cap)
	if err != nil {
		ctx.RespAutoError(ctx.Kit.CCError.Errorf(common.CCErrCommCommitTransactionFailed, err.Error()))
		return
	}

	ctx.RespEntity(nil)
}

// AbortTransaction to abort transaction
func (s *coreService) AbortTransaction(ctx *rest.Contexts) {
	cap := new(metadata.TxnCapable)
	if err := ctx.DecodeInto(cap); err != nil {
		ctx.RespErrorCodeOnly(common.CCErrCommHTTPInputInvalid, "decode transaction request body failed, err: %v", err)
		return
	}

	retry, err := mongodb.Client().AbortTransaction(ctx.Kit.Ctx, cap)
	if err != nil {
		ctx.RespAutoError(ctx.Kit.CCError.Errorf(common.CCErrCommCommitTransactionFailed, err.Error()))
		return
	}

	ctx.RespEntity(metadata.AbortTransactionResult{Retry: retry})
}
